==> quarkus-arc-deployment-1.4.1.Final-sources.jar: io/quarkus/arc/deployment/BeanArchiveProcessor$$accessor.java <==
package io.quarkus.arc.deployment;
public final class BeanArchiveProcessor$$accessor {
    private BeanArchiveProcessor$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_applicationArchivesBuildItem(Object __instance) {
        return ((BeanArchiveProcessor)__instance).applicationArchivesBuildItem;
    }
    @SuppressWarnings("unchecked")
    public static void set_applicationArchivesBuildItem(Object __instance, Object applicationArchivesBuildItem) {
        ((BeanArchiveProcessor)__instance).applicationArchivesBuildItem = (io.quarkus.deployment.builditem.ApplicationArchivesBuildItem)applicationArchivesBuildItem;
    }
    @SuppressWarnings("unchecked")
    public static Object get_additionalBeanDefiningAnnotations(Object __instance) {
        return ((BeanArchiveProcessor)__instance).additionalBeanDefiningAnnotations;
    }
    @SuppressWarnings("unchecked")
    public static void set_additionalBeanDefiningAnnotations(Object __instance, Object additionalBeanDefiningAnnotations) {
        ((BeanArchiveProcessor)__instance).additionalBeanDefiningAnnotations = (java.util.List<BeanDefiningAnnotationBuildItem>)additionalBeanDefiningAnnotations;
    }
    @SuppressWarnings("unchecked")
    public static Object get_additionalBeans(Object __instance) {
        return ((BeanArchiveProcessor)__instance).additionalBeans;
    }
    @SuppressWarnings("unchecked")
    public static void set_additionalBeans(Object __instance, Object additionalBeans) {
        ((BeanArchiveProcessor)__instance).additionalBeans = (java.util.List<AdditionalBeanBuildItem>)additionalBeans;
    }
    @SuppressWarnings("unchecked")
    public static Object get_generatedBeans(Object __instance) {
        return ((BeanArchiveProcessor)__instance).generatedBeans;
    }
    @SuppressWarnings("unchecked")
    public static void set_generatedBeans(Object __instance, Object generatedBeans) {
        ((BeanArchiveProcessor)__instance).generatedBeans = (java.util.List<GeneratedBeanBuildItem>)generatedBeans;
    }
    @SuppressWarnings("unchecked")
    public static Object get_generatedClass(Object __instance) {
        return ((BeanArchiveProcessor)__instance).generatedClass;
    }
    @SuppressWarnings("unchecked")
    public static void set_generatedClass(Object __instance, Object generatedClass) {
        ((BeanArchiveProcessor)__instance).generatedClass = (io.quarkus.deployment.annotations.BuildProducer<io.quarkus.deployment.builditem.GeneratedClassBuildItem>)generatedClass;
    }
    public static Object construct() {
        return new BeanArchiveProcessor();
    }
}

==> quarkus-arc-deployment-1.7.0.Final-sources.jar: io/quarkus/arc/deployment/BeanArchiveProcessor$$accessor.java <==
package io.quarkus.arc.deployment;
public final class BeanArchiveProcessor$$accessor {
    private BeanArchiveProcessor$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_applicationArchivesBuildItem(Object __instance) {
        return ((BeanArchiveProcessor)__instance).applicationArchivesBuildItem;
    }
    @SuppressWarnings("unchecked")
    public static void set_applicationArchivesBuildItem(Object __instance, Object applicationArchivesBuildItem) {
        ((BeanArchiveProcessor)__instance).applicationArchivesBuildItem = (io.quarkus.deployment.builditem.ApplicationArchivesBuildItem)applicationArchivesBuildItem;
    }
    @SuppressWarnings("unchecked")
    public static Object get_additionalBeanDefiningAnnotations(Object __instance) {
        return ((BeanArchiveProcessor)__instance).additionalBeanDefiningAnnotations;
    }
    @SuppressWarnings("unchecked")
    public static void set_additionalBeanDefiningAnnotations(Object __instance, Object additionalBeanDefiningAnnotations) {
        ((BeanArchiveProcessor)__instance).additionalBeanDefiningAnnotations = (java.util.List<BeanDefiningAnnotationBuildItem>)additionalBeanDefiningAnnotations;
    }
    @SuppressWarnings("unchecked")
    public static Object get_additionalBeans(Object __instance) {
        return ((BeanArchiveProcessor)__instance).additionalBeans;
    }
    @SuppressWarnings("unchecked")
    public static void set_additionalBeans(Object __instance, Object additionalBeans) {
        ((BeanArchiveProcessor)__instance).additionalBeans = (java.util.List<AdditionalBeanBuildItem>)additionalBeans;
    }
    @SuppressWarnings("unchecked")
    public static Object get_generatedBeans(Object __instance) {
        return ((BeanArchiveProcessor)__instance).generatedBeans;
    }
    @SuppressWarnings("unchecked")
    public static void set_generatedBeans(Object __instance, Object generatedBeans) {
        ((BeanArchiveProcessor)__instance).generatedBeans = (java.util.List<GeneratedBeanBuildItem>)generatedBeans;
    }
    @SuppressWarnings("unchecked")
    public static Object get_generatedClass(Object __instance) {
        return ((BeanArchiveProcessor)__instance).generatedClass;
    }
    @SuppressWarnings("unchecked")
    public static void set_generatedClass(Object __instance, Object generatedClass) {
        ((BeanArchiveProcessor)__instance).generatedClass = (io.quarkus.deployment.annotations.BuildProducer<io.quarkus.deployment.builditem.GeneratedClassBuildItem>)generatedClass;
    }
    @SuppressWarnings("unchecked")
    public static Object get_config(Object __instance) {
        return ((BeanArchiveProcessor)__instance).config;
    }
    @SuppressWarnings("unchecked")
    public static void set_config(Object __instance, Object config) {
        ((BeanArchiveProcessor)__instance).config = (ArcConfig)config;
    }
}
